import { HttpClient } from '@angular/common/http';
import { Component, OnInit } from '@angular/core';
import { ConfigService } from '@services/config.service';
import { ToastrService } from 'ngx-toastr';
import { MatTabChangeEvent } from '@angular/material/tabs';

@Component({
  selector: 'app-global-status',
  templateUrl: './global-status.component.html',
  styleUrl: './global-status.component.css'
})
export class GlobalStatusComponent implements OnInit {
  baseUrl: string;
  ogBootApiUrl: string;
  loading: boolean = false;
  ogBootDiskUsage: any = {};
  ogBootSubnets: any[] = [];
  ogBootServicesStatus: any = {};
  installedOgLives: any[] = [];
  diskUsageChartData: any[] = [];
  gradient: boolean = true;
  showLabels: boolean = true;
  isDoughnut: boolean = true;
  colorScheme: any = {
    domain: ['#df200d', '#26a700']
  };
  view: [number, number] = [400, 220];

  constructor(
    private configService: ConfigService,
    private http: HttpClient,
    private toastService: ToastrService
  ) {
    this.baseUrl = this.configService.apiUrl;
    this.ogBootApiUrl = `${this.baseUrl}/og-boot/status`;
  }

  ngOnInit(): void {
    this.loadOgBootStatus();
  }

  loadOgBootStatus(): void {
    this.loading = true;
    this.http.get<any>(this.ogBootApiUrl).subscribe({
      next: data => {
        this.ogBootDiskUsage = data.message.disk_usage;
        this.ogBootSubnets = data.message.subnets;
        this.ogBootServicesStatus = data.message.services_status;
        this.installedOgLives = data.message.installed_oglives;
        this.diskUsageChartData = [
          { name: 'Usado', value: parseFloat(this.ogBootDiskUsage.used) },
          { name: 'Disponible', value: parseFloat(this.ogBootDiskUsage.available) }
        ];
        this.loading = false;
      },
      error: error => {
        this.toastService.error('Error al sincronizar ogBoot');
        console.log(error);
        this.loading = false;
      }
    });
  }

  onTabChange(event: MatTabChangeEvent): void {
    if (event.tab.textLabel === 'OgBoot') {
      this.loadOgBootStatus();
    }
  }

  getServices(): { name: string, status: string }[] {
    if (!this.ogBootServicesStatus) {
      return [];
    }
    const services = Object.keys(this.ogBootServicesStatus).map(key => ({
      name: key,
      status: this.ogBootServicesStatus[key]
    }))
    return services;
  }

  formatBytes(bytes: number): string {
    if (bytes >= 1e9) {
      return (bytes / 1e9).toFixed(2) + ' GB';
    } else if (bytes >= 1e6) {
      return (bytes / 1e6).toFixed(2) + ' MB';
    } else if (bytes >= 1e3) {
      return (bytes / 1e3).toFixed(2) + ' KB';
    } else {
      return bytes + ' B';
    }
  }
}
